@@ -5,14 +5,8 @@ use crate::str_term::str_types::*;
 use crate::DiagnosticMessage;
 use crate::{lex_states::*, LexState};
 
-pub(crate) trait ParsePercent {
-    fn percent_unknown(&mut self, term: &MaybeByte) -> i32;
-    fn percent_quotation(&mut self, c: &mut MaybeByte, ptok: usize) -> i32;
-    fn parse_percent(&mut self, space_seen: bool, last_state: LexState) -> i32;
-}
-
-impl ParsePercent for Lexer {
-    fn percent_unknown(&mut self, term: &MaybeByte) -> i32 {
+impl Lexer {
+    fn percent_unknown(&mut self, term: MaybeByte) -> i32 {
         self.buffer.pushback(term);
         let len = self.multibyte_char_len(self.buffer.pcur);
         match len {
@@ -31,19 +25,19 @@ impl ParsePercent for Lexer {
         let mut paren: Option<u8>;
 
         if c.is_eof() || !c.is_alnum() {
-            term = c.clone();
+            term = *c;
             if !c.is_ascii() {
-                return self.percent_unknown(&term);
+                return self.percent_unknown(term);
             }
             *c = MaybeByte::new(b'Q');
         } else {
             term = self.nextc();
             if term.is_alnum() {
-                return self.percent_unknown(&term);
+                return self.percent_unknown(term);
             }
         }
 
-        let mut term = match term.to_option() {
+        let mut term = match term.as_option() {
             None => {
                 self.compile_error(
                     DiagnosticMessage::new_unterminated_quoted_string(),
@@ -68,7 +62,7 @@ impl ParsePercent for Lexer {
         }
 
         self.buffer.ptok = ptok - 1;
-        match c.to_option() {
+        match c.as_option() {
             Some(b'Q') => {
                 self.strterm = self.new_strterm(str_dquote, term, paren, None);
                 Self::tSTRING_BEG
@@ -116,7 +110,7 @@ impl ParsePercent for Lexer {
         }
     }
 
-    fn parse_percent(&mut self, space_seen: bool, last_state: LexState) -> i32 {
+    pub(crate) fn parse_percent(&mut self, space_seen: bool, last_state: LexState) -> i32 {
         let mut c: MaybeByte;
         let ptok = self.buffer.pcur;
 
@@ -131,7 +125,7 @@ impl ParsePercent for Lexer {
             self.lex_state.set(EXPR_BEG);
             return Self::tOP_ASGN;
         }
-        if self.lex_state.is_spacearg(&c, space_seen)
+        if self.lex_state.is_spacearg(c, space_seen)
             || (self.lex_state.is_some(EXPR_FITEM) && c == b's')
         {
             return self.percent_quotation(&mut c, ptok);
@@ -141,14 +135,14 @@ impl ParsePercent for Lexer {
         } else {
             EXPR_BEG
         });
-        self.buffer.pushback(&c);
+        self.buffer.pushback(c);
         self.warn_balanced(
             Self::tPERCENT,
             "%%",
             "string literal",
-            &c,
+            c,
             space_seen,
-            &last_state,
+            last_state,
         )
     }
 }
