@@ -1,8 +1,9 @@
+crate::use_native_or_external!(Maybe);
 crate::use_native_or_external!(StringPtr);
 crate::use_native_or_external!(List);
 crate::use_native_or_external!(SharedByteList);
 
-use crate::source::MaybeDecoder;
+use crate::source::Decoder;
 use crate::source::SourceLine;
 use crate::source::{decode_input, DecodedInput, InputError};
 
@@ -11,12 +12,12 @@ use crate::source::{decode_input, DecodedInput, InputError};
 #[repr(C)]
 pub struct Input {
     pub(crate) decoded: DecodedInput,
-    decoder: MaybeDecoder,
+    decoder: Maybe<Decoder>,
 }
 
 impl Input {
     /// Constructs a new input
-    pub fn new<Name>(name: Name, decoder: MaybeDecoder) -> Self
+    pub fn new<Name>(name: Name, decoder: Maybe<Decoder>) -> Self
     where
         Name: Into<StringPtr>,
     {
@@ -32,11 +33,7 @@ impl Input {
     }
 
     pub(crate) fn byte_at(&self, idx: usize) -> Option<u8> {
-        if let Some(c) = self.decoded.bytes().get(idx) {
-            Some(*c)
-        } else {
-            None
-        }
+        self.decoded.bytes().get(idx).copied()
     }
 
     pub(crate) fn unchecked_byte_at(&self, idx: usize) -> u8 {
@@ -63,7 +60,7 @@ impl Input {
     // }
 
     pub(crate) fn line_at(&self, idx: usize) -> &SourceLine {
-        &self.decoded.line_at(idx)
+        self.decoded.line_at(idx)
     }
 
     pub(crate) fn lines_count(&self) -> usize {
